#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .symbol import symbol as symbol_cls
from .size_1 import size as size_cls
from .color import color as color_cls

class markers_child(Group):
    """
    'child_object_type' of markers.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['symbol', 'size', 'color']

    _child_classes = dict(
        symbol=symbol_cls,
        size=size_cls,
        color=color_cls,
    )

    return_type = "<object object at 0x7fc3bc192c10>"
