#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .coupling import coupling as coupling_cls
from .helper_session_setup import helper_session_setup as helper_session_setup_cls
from .helper_session import helper_session as helper_session_cls

class set(Group):
    """
    'set' child.
    """

    fluent_name = "set"

    child_names = \
        ['coupling', 'helper_session_setup', 'helper_session']

    _child_classes = dict(
        coupling=coupling_cls,
        helper_session_setup=helper_session_setup_cls,
        helper_session=helper_session_cls,
    )

    return_type = "<object object at 0x7f5bb1149940>"
