#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class beta_factor_omega_equation(Real):
    """
    Specify the beta factor in the omega equation.
    """

    fluent_name = "beta-factor-omega-equation"

    return_type = "<object object at 0x7fa445dc8ad0>"
