#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_3 import option as option_cls
from .step_size import step_size as step_size_cls
from .tolerance_1 import tolerance as tolerance_cls

class accuracy_control(Group):
    """
    'accuracy_control' child.
    """

    fluent_name = "accuracy-control"

    child_names = \
        ['option', 'step_size', 'tolerance']

    _child_classes = dict(
        option=option_cls,
        step_size=step_size_cls,
        tolerance=tolerance_cls,
    )

    return_type = "<object object at 0x7f5bb12540f0>"
