#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_10 import option as option_cls
from .value_1 import value as value_cls
from .orthotropic_structure_nu import orthotropic_structure_nu as orthotropic_structure_nu_cls
from .user_defined_function import user_defined_function as user_defined_function_cls

class struct_poisson_ratio(Group):
    """
    'struct_poisson_ratio' child.
    """

    fluent_name = "struct-poisson-ratio"

    child_names = \
        ['option', 'value', 'orthotropic_structure_nu',
         'user_defined_function']

    _child_classes = dict(
        option=option_cls,
        value=value_cls,
        orthotropic_structure_nu=orthotropic_structure_nu_cls,
        user_defined_function=user_defined_function_cls,
    )

    return_type = "<object object at 0x7fc3bcfe37b0>"
